;; call package-initialize manually, disable automatic initialization:
(setq package-enable-at-startup nil)

;; Packages
(load "~/.emacs.d/packages.el")

;; Convenient functions
(load "~/.emacs.d/functions.el")

;; Tab width
(setq-default tab-width 4)
;; No tabs when editing Lisp
;;(add-hook 'lisp-mode-hook '(setq indent-tabs-mode nil))
;;(add-hook 'scheme-mode-hook '(setq indent-tabs-mode nil))
(setq-default indent-tabs-mode nil)


;; Remove useless stuff
(menu-bar-mode 0)
(tool-bar-mode 0)
(scroll-bar-mode 0)

;; UTF-8!!!!
(set-language-environment "UTF-8")

;; Appearance
(set-frame-font "Gohu Gohufont 11")
(set-face-italic 'font-lock-comment-face nil)  ; disable italics
										; theme set in packages.el
(add-to-list 'custom-theme-load-path "~/.emacs.d/themes/")
(load-theme 'magik t)
(global-linum-mode)
(blink-cursor-mode nil)
(when window-system (global-hl-line-mode t))
(show-paren-mode t)
(setq confirm-kill-emacs 'y-or-n-p)

;; Mode line
(line-number-mode t)
(column-number-mode t)
(setq display-time-24hr-format t)
(display-time-mode t)

;; disable creation of backup files
(setq make-backup-files nil)
(setq auto-save-default nil)

;; pretty lambdas
;(setq-default prettify-symbols-alist '(("lambda" . 955)))
;(global-prettify-symbols-mode 1)

;; Y or N instead of Yes or No
(defalias 'yes-or-no-p 'y-or-n-p)

;; Smaller skips when cursor reaches end of screen
(setq scroll-conservatively 100)

;; Disable bell
(setq ring-bell-function 'ignore)

;; Subword for camelCase words
(global-subword-mode t)

;; Electric pair mode
(setq electric-pair-pairs '((?\( . ?\))
							(?\[ . ?\])
							(?\{ . ?\})
							(?\" . ?\")
							))
(electric-pair-mode t)

(setq user-mail-address "opfez@disroot.org")
(setq user-full-name "opFez")
(setq add-log-mailing-address "opfez@disroot.org")

;; windmove
(global-set-key (kbd "C-S-j")  'windmove-left)
(global-set-key (kbd "C-S-k")  'windmove-down)
(global-set-key (kbd "C-S-l")  'windmove-up)
(global-set-key (kbd "C-:")    'windmove-right)

;; Terminal
(defvar term-shell "/bin/mksh")
(defadvice ansi-term (before force-bash)
  (interactive (list term-shell)))
(ad-activate 'ansi-term)

;; C configuration
(setq c-default-style "linux"
      c-basic-offset 4)

;; Scheme configuration
(setq geiser-active-implementations '(guile))

;; Disable bold fonts
(defun remap-faces-default-attributes ()
   (let ((family (face-attribute 'default :family))
         (height (face-attribute 'default :height)))
     (mapcar (lambda (face)
              (face-remap-add-relative
               face :family family :slant 'normal :weight 'normal :height height))
			 (face-list))))

(when (display-graphic-p)
   (add-hook 'minibuffer-setup-hook 'remap-faces-default-attributes)
   (add-hook 'change-major-mode-after-body-hook 'remap-faces-default-attributes))

;; Eshell
(defalias 'open 'find-file-other-window)
(defalias 'clean 'eshell/clear-scrollback)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(custom-set-variables
 ;; custom-set-variables was added by Custom.
 ;; If you edit it by hand, you could mess it up, so be careful.
 ;; Your init file should contain only one such instance.
 ;; If there is more than one, they won't work right.
 '(column-number-mode t)
 '(custom-safe-themes
   '("a6473f7abf949f4a6a1a9cc0dd37ea2e35ba3cea65d3442b98d65c5c5c5cb8d7" "b026761932dac55edfc103de7267ab1db5cd7cc183e06654a2be976cf3a09b9c" "2eeeb1813d66b7d1b858ecf7e4623f774ee555f4b6c1e6de93a1875c03af41de" "5a5e51dc0d54d7626f182dcc1712ed0bad80085db52da3fbe737be4f58d983d0" "4c5f4e96bbde8ab012c661b04c887d9cf65ee9fc37abcce661aabd3a098a69e9" "9c25bd583aa28e4a96af84c9bcf4b5c917bb2ec907ac9d5ab745e54b27104ec6" default))
 '(display-time-mode t)
 '(package-selected-packages
   '(basic-theme geiser-chicken geiser-guile disaster multiple-cursors nasm-mode carp-mode flycheck ido-mode move-text undo-tree sorcery-theme autothemer rust-mode paredit forth-mode avy swiper auto-package-update magit expand-region go-mode tao-themes tao-theme almost-mono-themes use-package))
 '(pdf-view-midnight-colors '("#dddddd" . "#000000"))
 '(show-paren-mode t)
 '(tool-bar-mode nil))
(custom-set-faces
 ;; custom-set-faces was added by Custom.
 ;; If you edit it by hand, you could mess it up, so be careful.
 ;; Your init file should contain only one such instance.
 ;; If there is more than one, they won't work right.
 )
;; 
(put 'downcase-region 'disabled nil)
